SQLAlchemy 0.3 Documentation - module sqlalchemy.engine.default

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.engine.default

### class DefaultDialect(Dialect)

Default implementation of Dialect

def __init__(self, convert_unicode=False, encoding='utf-8', default_paramstyle='named', paramstyle=None, dbapi=None, **kwargs)
def convert_compiled_params(self, parameters)
def create_execution_context(self, **kwargs)
def defaultrunner(self, connection)
def do_begin(self, connection)

Implementations might want to put logic here for turning autocommit on/off, etc.

def do_commit(self, connection)

Implementations might want to put logic here for turning autocommit on/off, etc.

def do_execute(self, cursor, statement, parameters, **kwargs)
def do_executemany(self, cursor, statement, parameters, **kwargs)
def do_rollback(self, connection)

Implementations might want to put logic here for turning autocommit on/off, etc.

def is_disconnect(self, e)
ischema = property()

returns an ISchema object for this engine, which allows access to information_schema tables (if supported)

def max_identifier_length(self)
def oid_column_name(self, column)
paramstyle = property()
def supports_alter(self)
def supports_sane_rowcount(self)
def supports_unicode_statements(self)

indicate whether the DBAPI can receive SQL statements as Python unicode strings

def type_descriptor(self, typeobj)

Provide a database-specific `TypeEngine` object, given the generic object which comes from the types module.

Subclasses will usually use the `adapt_type()` method in the types module to make this job easy.

back to section top

### class DefaultExecutionContext(ExecutionContext)

def __init__(self, dialect, connection, compiled=None, compiled_parameters=None, statement=None, parameters=None)
def create_cursor(self)
engine = property()
def get_result_proxy(self)
def get_rowcount(self)
def is_select(self)
def last_inserted_ids(self)
def last_inserted_params(self)
def last_updated_params(self)
def lastrow_has_defaults(self)
def post_exec(self)
def pre_exec(self)
def set_input_sizes(self)

Given a cursor and ClauseParameters, call the appropriate style of `setinputsizes()` on the cursor, using DBAPI types from the bind parameter's `TypeEngine` objects.

def supports_sane_rowcount(self)
back to section top

### class PoolConnectionProvider(ConnectionProvider)

def __init__(self, url, pool)
def dispose(self)
def get_connection(self)
back to section top